.. crimsonslate-tools documentation master file, created by
   sphinx-quickstart on Sat May 31 16:22:52 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

crimsonslate-tools documentation
================================


.. toctree::
    :maxdepth: 2
    :caption: Contents:

    views/index.rst
